@@ -1,20 +1,24 @@
 ﻿/*
- * FCKeditor - The text editor for internet
- * Copyright (C) 2003-2006 Frederico Caldeira Knabben
- * 
- * Licensed under the terms of the GNU Lesser General Public License:
- * 		http://www.opensource.org/licenses/lgpl-license.php
- * 
- * For further information visit:
- * 		http://www.fckeditor.net/
- * 
- * "Support Open Source software. What about a donation today?"
- * 
- * File Name: ru.js
- * 	Russian language file.
- * 
- * File Authors:
- * 		Andrey Grebnev (andrey.grebnev@blandware.com)
+ * FCKeditor - The text editor for Internet - http://www.fckeditor.net
+ * Copyright (C) 2003-2008 Frederico Caldeira Knabben
+ *
+ * == BEGIN LICENSE ==
+ *
+ * Licensed under the terms of any of the following licenses at your
+ * choice:
+ *
+ *  - GNU General Public License Version 2 or later (the "GPL")
+ *    http://www.gnu.org/licenses/gpl.html
+ *
+ *  - GNU Lesser General Public License Version 2.1 or later (the "LGPL")
+ *    http://www.gnu.org/licenses/lgpl.html
+ *
+ *  - Mozilla Public License Version 1.1 or later (the "MPL")
+ *    http://www.mozilla.org/MPL/MPL-1.1.html
+ *
+ * == END LICENSE ==
+ *
+ * Russian language file.
  */
 
 var FCKLang =
@@ -40,7 +44,9 @@ RemoveFormat		: "Убрать форматирование",
 InsertLinkLbl		: "Ссылка",
 InsertLink			: "Вставить/Редактировать ссылку",
 RemoveLink			: "Убрать ссылку",
+VisitLink			: "Open Link",	//MISSING
 Anchor				: "Вставить/Редактировать якорь",
+AnchorDelete		: "Убрать якорь",
 InsertImageLbl		: "Изображение",
 InsertImage			: "Вставить/Редактировать изображение",
 InsertFlashLbl		: "Flash",
@@ -66,6 +72,10 @@ RightJustify		: "По правому краю",
 BlockJustify		: "По ширине",
 DecreaseIndent		: "Уменьшить отступ",
 IncreaseIndent		: "Увеличить отступ",
+Blockquote			: "Цитата",
+CreateDiv			: "Create Div Container",	//MISSING
+EditDiv				: "Edit Div Container",	//MISSING
+DeleteDiv			: "Remove Div Container",	//MISSING
 Undo				: "Отменить",
 Redo				: "Повторить",
 NumberedListLbl		: "Нумерованный список",
@@ -99,20 +109,27 @@ SelectionField	: "Список",
 ImageButton		: "Кнопка с изображением",
 
 FitWindow		: "Развернуть окно редактора",
+ShowBlocks		: "Показать блоки",
 
 // Context Menu
 EditLink			: "Вставить ссылку",
 CellCM				: "Ячейка",
 RowCM				: "Строка",
 ColumnCM			: "Колонка",
-InsertRow			: "Вставить строку",
+InsertRowAfter		: "Вставить строку после",
+InsertRowBefore		: "Вставить строку до",
 DeleteRows			: "Удалить строки",
-InsertColumn		: "Вставить колонку",
+InsertColumnAfter	: "Вставить колонку после",
+InsertColumnBefore	: "Вставить колонку до",
 DeleteColumns		: "Удалить колонки",
-InsertCell			: "Вставить ячейку",
+InsertCellAfter		: "Вставить ячейку после",
+InsertCellBefore	: "Вставить ячейку до",
 DeleteCells			: "Удалить ячейки",
 MergeCells			: "Соединить ячейки",
-SplitCell			: "Разбить ячейку",
+MergeRight			: "Соединить вправо",
+MergeDown			: "Соединить вниз",
+HorizontalSplitCell	: "Разбить ячейку горизонтально",
+VerticalSplitCell	: "Разбить ячейку вертикально",
 TableDelete			: "Удалить таблицу",
 CellProperties		: "Свойства ячейки",
 TableProperties		: "Свойства таблицы",
@@ -133,7 +150,7 @@ FormProp			: "Свойства формы",
 FontFormats			: "Нормальный;Форматированный;Адрес;Заголовок 1;Заголовок 2;Заголовок 3;Заголовок 4;Заголовок 5;Заголовок 6;Нормальный (DIV)",
 
 // Alerts and Messages
-ProcessingXHTML		: "Обработка XHTML. Пожалуйста подождите...",
+ProcessingXHTML		: "Обработка XHTML. Пожалуйста, подождите...",
 Done				: "Сделано",
 PasteWordConfirm	: "Текст, который вы хотите вставить, похож на копируемый из Word. Вы хотите очистить его перед вставкой?",
 NotCompatiblePaste	: "Эта команда доступна для Internet Explorer версии 5.5 или выше. Вы хотите вставить без очистки?",
@@ -143,7 +160,8 @@ NotImplemented		: "Команда не реализована",
 UnknownToolbarSet	: "Панель инструментов \"%1\" не существует",
 NoActiveX			: "Настройки безопасности вашего браузера могут ограничивать некоторые свойства редактора. Вы должны включить опцию \"Запускать элементы управления ActiveX и плугины\". Вы можете видеть ошибки и замечать отсутствие возможностей.",
 BrowseServerBlocked : "Ресурсы браузера не могут быть открыты. Проверьте что блокировки всплывающих окон выключены.",
-DialogBlocked		: "Не возможно открыть окно диалога. Проверьте что блокировки всплывающих окон выключены.",
+DialogBlocked		: "Невозможно открыть окно диалога. Проверьте что блокировки всплывающих окон выключены.",
+VisitLinkBlocked	: "It was not possible to open a new window. Make sure all popup blockers are disabled.",	//MISSING
 
 // Dialogs
 DlgBtnOK			: "ОК",
@@ -153,7 +171,7 @@ DlgBtnBrowseServer	: "Просмотреть на сервере",
 DlgAdvancedTag		: "Расширенный",
 DlgOpOther			: "<Другое>",
 DlgInfoTab			: "Информация",
-DlgAlertUrl			: "Пожалуйста вставьте URL",
+DlgAlertUrl			: "Пожалуйста, вставьте URL",
 
 // General Dialogs Labels
 DlgGenNotSet		: "<не определено>",
@@ -197,7 +215,7 @@ DlgImgAlignRight	: "По правому краю",
 DlgImgAlignTextTop	: "Текст наверху",
 DlgImgAlignTop		: "По верху",
 DlgImgPreview		: "Предварительный просмотр",
-DlgImgAlertUrl		: "Пожалуйста введите URL изображения",
+DlgImgAlertUrl		: "Пожалуйста, введите URL изображения",
 DlgImgLinkTab		: "Ссылка",
 
 // Flash Dialog
@@ -225,7 +243,7 @@ DlgLnkURL			: "URL",
 DlgLnkAnchorSel		: "Выберите якорь",
 DlgLnkAnchorByName	: "По имени якоря",
 DlgLnkAnchorById	: "По идентификатору элемента",
-DlgLnkNoAnchors		: "<Нет якорей доступных в этом документе>",
+DlgLnkNoAnchors		: "(Нет якорей доступных в этом документе)",
 DlgLnkEMail			: "Адрес эл. почты",
 DlgLnkEMailSubject	: "Заголовок сообщения",
 DlgLnkEMailBody		: "Тело сообщения",
@@ -255,9 +273,9 @@ DlgLnkPopHeight		: "Высота",
 DlgLnkPopLeft		: "Позиция слева",
 DlgLnkPopTop		: "Позиция сверху",
 
-DlnLnkMsgNoUrl		: "Пожалуйста введите URL ссылки",
-DlnLnkMsgNoEMail	: "Пожалуйста введите адрес эл. почты",
-DlnLnkMsgNoAnchor	: "Пожалуйста выберете якорь",
+DlnLnkMsgNoUrl		: "Пожалуйста, введите URL ссылки",
+DlnLnkMsgNoEMail	: "Пожалуйста, введите адрес эл. почты",
+DlnLnkMsgNoAnchor	: "Пожалуйста, выберете якорь",
 DlnLnkMsgInvPopName	: "Название вспывающего окна должно начинаться буквы и не может содержать пробелов",
 
 // Color Dialog
@@ -318,6 +336,9 @@ DlgCellBackColor	: "Цвет фона",
 DlgCellBorderColor	: "Цвет бордюра",
 DlgCellBtnSelect	: "Выберите...",
 
+// Find and Replace Dialog
+DlgFindAndReplaceTitle	: "Найти и заменить",
+
 // Find Dialog
 DlgFindTitle		: "Найти",
 DlgFindFindBtn		: "Найти",
@@ -333,17 +354,16 @@ DlgReplaceReplAllBtn	: "Заменить все",
 DlgReplaceWordChk		: "Совпадение целых слов",
 
 // Paste Operations / Dialog
-PasteErrorPaste	: "Настройки безопасности вашего браузера не позволяют редактору автоматически выполнять операции вставки. Пожалуйста используйте клавиатуру для этого (Ctrl+V).",
-PasteErrorCut	: "Настройки безопасности вашего браузера не позволяют редактору автоматически выполнять операции вырезания. Пожалуйста используйте клавиатуру для этого (Ctrl+X).",
-PasteErrorCopy	: "Настройки безопасности вашего браузера не позволяют редактору автоматически выполнять операции копирования. Пожалуйста используйте клавиатуру для этого (Ctrl+C).",
+PasteErrorCut	: "Настройки безопасности вашего браузера не позволяют редактору автоматически выполнять операции вырезания. Пожалуйста, используйте клавиатуру для этого (Ctrl+X).",
+PasteErrorCopy	: "Настройки безопасности вашего браузера не позволяют редактору автоматически выполнять операции копирования. Пожалуйста, используйте клавиатуру для этого (Ctrl+C).",
 
 PasteAsText		: "Вставить только текст",
 PasteFromWord	: "Вставить из Word",
 
-DlgPasteMsg2	: "Пожалуйста вставьте текст в прямоугольник используя сочетание клавиш (<STRONG>Ctrl+V</STRONG>) и нажмите <STRONG>OK</STRONG>.",
+DlgPasteMsg2	: "Пожалуйста, вставьте текст в прямоугольник, используя сочетание клавиш (<STRONG>Ctrl+V</STRONG>), и нажмите <STRONG>OK</STRONG>.",
+DlgPasteSec		: "По причине настроек безопасности браузера, редактор не имеет доступа к данным буфера обмена напрямую. Вам необходимо вставить текст снова в это окно.",
 DlgPasteIgnoreFont		: "Игнорировать определения гарнитуры",
 DlgPasteRemoveStyles	: "Убрать определения стилей",
-DlgPasteCleanBox		: "Очистить",
 
 // Color Picker
 ColorAutomatic	: "Автоматический",
@@ -355,7 +375,7 @@ DocProps		: "Свойства документа",
 // Anchor Dialog
 DlgAnchorTitle		: "Свойства якоря",
 DlgAnchorName		: "Имя якоря",
-DlgAnchorErrorName	: "Пожалуйста введите имя якоря",
+DlgAnchorErrorName	: "Пожалуйста, введите имя якоря",
 
 // Speller Pages Dialog
 DlgSpellNotInDic		: "Нет в словаре",
@@ -447,8 +467,8 @@ DlgDocMetaTab		: "Мета данные",
 
 DlgDocPageTitle		: "Заголовок страницы",
 DlgDocLangDir		: "Направление текста",
-DlgDocLangDirLTR	: "Слева на право (LTR)",
-DlgDocLangDirRTL	: "Справа на лево (RTL)",
+DlgDocLangDirLTR	: "Слева направо (LTR)",
+DlgDocLangDirRTL	: "Справа налево (RTL)",
 DlgDocLangCode		: "Код языка",
 DlgDocCharSet		: "Кодировка набора символов",
 DlgDocCharSetCE		: "Центрально-европейская",
@@ -486,8 +506,8 @@ DlgDocPreview		: "Предварительный просмотр",
 // Templates Dialog
 Templates			: "Шаблоны",
 DlgTemplatesTitle	: "Шаблоны содержимого",
-DlgTemplatesSelMsg	: "Пожалуйста выберете шаблон для открытия в редакторе<br>(текущее содержимое будет потеряно):",
-DlgTemplatesLoading	: "Загрузка списка шаблонов. Пожалуйста подождите...",
+DlgTemplatesSelMsg	: "Пожалуйста, выберете шаблон для открытия в редакторе<br>(текущее содержимое будет потеряно):",
+DlgTemplatesLoading	: "Загрузка списка шаблонов. Пожалуйста, подождите...",
 DlgTemplatesNoTpl	: "(Ни одного шаблона не определено)",
 DlgTemplatesReplace	: "Заменить текущее содержание",
 
@@ -496,6 +516,11 @@ DlgAboutAboutTab	: "О программе",
 DlgAboutBrowserInfoTab	: "Информация браузера",
 DlgAboutLicenseTab	: "Лицензия",
 DlgAboutVersion		: "Версия",
-DlgAboutLicense		: "Лицензировано в соответствии с условиями GNU Lesser General Public License",
-DlgAboutInfo		: "Для большей информации, посетите"
-}
\ No newline at end of file
+DlgAboutInfo		: "Для большей информации, посетите",
+
+// Div Dialog
+DlgDivGeneralTab	: "General",	//MISSING
+DlgDivAdvancedTab	: "Advanced",	//MISSING
+DlgDivStyle		: "Style",	//MISSING
+DlgDivInlineStyle	: "Inline Style"	//MISSING
+};
