@@ -72,11 +72,11 @@ if (isset($_GET["doit"]) && (($GLOBALS["require_login"] && isSuperUser()) || !$G
 
   if ($userid && $deleteuser) {
     deleteUser($userid);
-    print sprintf($GLOBALS['I18N']->get('DelUser').'\n', $userid);
+    print sprintf($GLOBALS['I18N']->get('DelUser')."\n", $userid);
   }
 
   if ($deletebounce) {
-    print sprintf($GLOBALS['I18N']->get('DeletingB').'\n', $id);
+    print sprintf($GLOBALS['I18N']->get('DeletingB')."\n", $id);
     Sql_query("delete from {$tables["bounce"]} where id = $id");
     print $GLOBALS['I18N']->get('DoneAndLoading')."<br /><hr><br />\n";
     print PageLink2("bounces",$GLOBALS['I18N']->get('BackToBList'));
