@@ -1,4 +1,4 @@
-<?
+<?php
 
 if (!function_exists("checkAccess")) {
   print "Invalid Request";
