@@ -1,4 +1,4 @@
-<?
+<?php
 global $HTTP_POST_VARS,$HTTP_ENV_VARS,$HTTP_GET_VARS,$HTTP_SESSION_VARS;
 
 if ($HTTP_GET_VARS) {
