@@ -20,7 +20,7 @@ if (isset($_POST["action"])) {
 
         #print "New attribute: ".$_POST["name"][0]."<br/>";
         $query = sprintf('insert into %s (name,type,listorder,default_value,required,tablename) values("%s","%s",%d,"%s",%d,"%s")',
-        $tables["attribute"],addslashes($_POST["name"][0]),$_POST["type"][0],$_POST["listorder"][0],addslashes($_POST["default"][0]),$_POST["required"][0],$lc_name);
+        $tables["attribute"],sql_escape($_POST["name"][0]),sql_escape($_POST["type"][0]),$_POST["listorder"][0],sql_escape($_POST["default"][0]),$_POST["required"][0],$lc_name);
         Sql_Query($query);
         $insertid = Sql_Insert_id();
 
@@ -60,7 +60,7 @@ if (isset($_POST["action"])) {
         if ($_POST["type"][$id] != $existingtype)
         switch ($existingtype) {
           case "textline":case "hidden":case "date":
-          	 print "Converting ".$_POST["name"][$id]." from $existingtype to ".$_POST["type"][$id]."<br/>";
+          	 print "Converting ".htmlentities($_POST["name"][$id])." from $existingtype to ".htmlentities($_POST["type"][$id])."<br/>";
              switch ($_POST["type"][$id]) {
             	case "radio":
               case "checkboxgroup":
@@ -96,7 +96,7 @@ if (isset($_POST["action"])) {
             break;
           case "radio":case "select": case "checkbox":
             if ($_POST["type"][$id] != "date" && $_POST["type"][$id] != "hidden" && $_POST["type"][$id] != "textline") break;
-          	print "Converting ".$_POST["name"][$id]." from $existingtype to ".$_POST["type"][$id]."<br/>";
+          	print "Converting ".htmlentities($_POST["name"][$id])." from $existingtype to ".htmlentities($_POST["type"][$id])."<br/>";
             # we are turning a radio,select or checkbox into a hidden or textline field
             $valuereq = Sql_Query("select id,name from $table_prefix"."listattr_$req[1]");
             while ($row = Sql_Fetch_Row($valuereq))
@@ -105,7 +105,7 @@ if (isset($_POST["action"])) {
             break;
           case "checkboxgroup":
             if ($_POST["type"][$id] == "hidden" || $_POST["type"][$id] == "textline") {
-		         	 print $GLOBALS['I18N']->get('converting')." ".$_POST["name"][$id]." ".$GLOBALS['I18N']->get('from')." $existingtype ".$GLOBALS['I18N']->get('to')." ".$_POST["type"][$id]."<br/>";
+		         	 print $GLOBALS['I18N']->get('converting')." ".htmlentities($_POST["name"][$id])." ".$GLOBALS['I18N']->get('from')." $existingtype ".$GLOBALS['I18N']->get('to')." ".htmlentities($_POST["type"][$id])."<br/>";
             	# we are changing a checkbox group into a hidden or textline
               # take the first value!
               $valuereq = Sql_Query("select id,name from $table_prefix"."listattr_$req[1]");
@@ -123,7 +123,7 @@ if (isset($_POST["action"])) {
             break;
         }
         $query = sprintf('update %s set name = "%s" ,type = "%s" ,listorder = %d,default_value = "%s" ,required = %d where id = %d',
-        $tables["attribute"],addslashes($_POST["name"][$id]),$_POST["type"][$id],$_POST['listorder'][$id],sql_escape($_POST['default'][$id]),$_POST['required'][$id],$id);
+        $tables["attribute"],sql_escape($_POST["name"][$id]),sql_escape($_POST["type"][$id]),$_POST['listorder'][$id],sql_escape($_POST['default'][$id]),$_POST['required'][$id],$id);
         Sql_Query($query);
       }
     }
@@ -366,4 +366,4 @@ print'
 <input type=submit name="action" value="'.$GLOBALS['I18N']->get('savechanges').'">
 </form>
 
-';
\ No newline at end of file
+';
