@@ -1,6 +1,8 @@
 <p>Hier konfigurieren Sie PHPlist, indem Sie die f&uuml;r Ihre Website zutreffenden Parameter und Texte erfassen.
 Sie k&ouml;nnen dabei gewisse <b>Platzhalter</b> benutzen. Solche Platzhalter haben das Format <b>[EINTEXT]</b>,
 wobei EINTEXT variiert. N&uuml;tzliche Platzhalter sind beispielsweise:
+</p>
+<div class="placeholders">
 <ul>
 <li>WEBSITE - die Adresse Ihrer Website
 <li>DOMAIN - Ihre Domain
@@ -9,7 +11,7 @@ wobei EINTEXT variiert. N&uuml;tzliche Platzhalter sind beispielsweise:
 <li>PREFERENCESURL - die Adresse der Seite, auf der die Abonnenten Ihre pers&ouml;nlichen Daten bearbeiten k&ouml;nnen
 <li>CONFIRMATIONURL - die Adresse der Seite, auf der die Abonnenten ein Abonnement best&auml;tigen m&uuml;ssen
 </ul>
+</div>
 <!--For the header and the footer you can use the following code to include external documents:
 <br/>
 <b>[URL:&lt;Full URL of page to load&gt;]</b>-->
-</p>
