@@ -58,7 +58,7 @@ PHPlist a eu, en son temps, une liste de diffusion, mais elle a &eacute;t&eacute
 </ul>
 </p>
 <p><b><a name="bugtrack"></a>Bugtrack</b><br/>
-Pour signaler un bug, allez sur <a href="http://mantis.phplist.com/" target="_blank">http://mantis.tincan.co.uk</a>
+Pour signaler un bug, allez sur <a href="http://mantis.tincan.co.uk/" target="_blank">http://mantis.tincan.co.uk</a>
 et cr&eacute;&eacute;z-vous un compte.  Vous recevrez un mot de passe par email.<br/>
 Vous pouvez ensuite rentrer dans le syst&egrave;me "mantis" et soumettre votre rapport.</p>
 <p>Voici les informations sur votre syst&egrave;me:</p>
