@@ -1,3 +1,3 @@
 
 <p>Deze pagina toont de beschikbare statistieken. Het is momenteel nog steeds een beetje ruw en zal moeten worden geupdate in volgende versies.</p>
-<p>Post jou commentaar en suggesties op <a href="http://mantis.phplist.com">Mantis</a></p>
\ No newline at end of file
+<p>Post jou commentaar en suggesties op <a href="http://mantis.tincan.co.uk">Mantis</a></p>
\ No newline at end of file
