@@ -3,7 +3,7 @@
 $lan = array(
   'existingusers' => "Utilisateurs Existants",
   'nonexistingusers' => "Utilisateurs Non Existants",
-  'existcheckintro' => '<p>Page pour v&eacute;rifier l&rsquo;entr&eacute;e des utilisateurs dans la base de donn&eacute;es</p>',
+  'existcheckintro' => 'Page pour v&eacute;rifier l&rsquo;entr&eacute;e des utilisateurs dans la base de donn&eacute;es',
   'whatistype' => 'Quel est le type d&rsquo;information que vous souhaitez v&eacute;rifier',
   "foreignkey" => "Foreign Key (cl&eacute; &eacute;trang&egrave;re)",
   "email" => "Email",
