@@ -4,26 +4,26 @@ $lan = array(
   'Number of %s rules: %d' => 'N&uacute;mero de %s regras: %d',
   'active' => 'ativa',
   'candidate' => 'candidata',
-  'Bounce Regular Expressions' => 'Formas t&iacute;picas de emails com problema',
+  'Bounce Regular Expressions' => 'Express&otilde;es regulares para emails de erro',
   'rule' => 'regra',
-  'expression' => 'forma',
-  'action' => 'a&ccedil&aatilde;o',
-  '#bncs' => '#bncs',
-  'tag' => 'r&oacute;tulo',
+  'expression' => 'express&atilde;o',
+  'action' => 'a&ccedil&atilde;o',
+  '#bncs' => '#erros',
+  'tag' => 'marcar',
   'order' => 'ordem',
   'del' => 'apagar',
-  'with tagged rules: ' => 'com regras rotuladas: ',
+  'with tagged rules: ' => 'com regras marcadas: ',
   'delete' => 'apagar',
   'make inactive' => 'tornar inativa',
-  'Save Changes' => 'Salvar Altera&ccedil;&oatilde;es',
+  'Save Changes' => 'Salvar Altera&ccedil;&otilde;es',
   'add a new rule' => 'adicionar uma nova regra',
-  'Regular Expression' => 'Forma T&iacute;pica',
-  'Memo for this rule' => 'Memorizar essa Regra',
+  'Regular Expression' => 'Express&atilde;o Regular',
+  'Memo for this rule' => 'Memo para esta regra',
   'Add new Rule' => 'Adicionar nova regra',
   'make active' => 'tornar ativa',
   'No Rules found' => 'Nenhuma Regra foi encontrada',
   'match' => 'verificar',
-  'That rule exists already' => 'Essa regra j&acute; existe',
+  'That rule exists already' => 'Essa regra j&aacute; existe',
 );
 
 ?>
