@@ -6,7 +6,7 @@ $lan = array(
  'delete' => 'apagar',
  'n/a' => 'n/d',
  'No lists available, use Add to add one' => 'Nenhuma lista encontrada, use Adicionar para incluir uma',
- 'No' => 'N&atilde;o',
+ 'No' => 'No.',
  'Name' => 'Nome',
  'Order' => 'Ordem',
  'Functions' => 'Fun&ccedil;&otilde;es',
