@@ -1,7 +1,7 @@
 <?php 
 $lan = array(
 
-  'subscribe pages' => 'P&aacute;ginas de Inscri&ccedil&aatildeo',
+  'subscribe pages' => 'P&aacute;ginas de Inscri&ccedil&atilde;o',
   'deleted' => 'Apagada',
   'add_new' => 'Adicionar uma nova',
   'title' => 't&iacute;tulo',
@@ -10,7 +10,7 @@ $lan = array(
   'view' => 'exibir',
   'status' => 'estatus',
   'owner' => 'administrador',
-  'default' => 'padr&aatilde;o',
+  'default' => 'padr&atilde;o',
   'active' => 'ativa',
   'not active' => 'inativa',
 
