@@ -1,14 +1,18 @@
 <?php
 $lan = array( 
- 'you only have privileges to view this page, not change any of the information' => 'Voc&ecirc; s&oacute; tem permiss&aatilde;o de ver esta p&aacute;gina, mas n&aatilde;o pode alterar nenhuma informa&ccedil;&aatilde;o',
- 'no such User' => 'Este usu&aacute;rio n&aatilde;o existe',
+ 'you only have privileges to view this page, not change any of the information' => 'Voc&ecirc; s&oacute; tem permiss&atilde;o de ver esta p&aacute;gina, mas n&atilde;o pode alterar nenhuma informa&ccedil;&atilde;o',
+ 'no such User' => 'Este usu&aacute;rio n&atilde;o existe',
  'view' => 'Exibir',
+ 'sent' => 'enviada em',
+ 'viewed' => 'vista em',
+ 'responsetime' => 'tempo resposta',
+ 'average' => 'media',
  'user is Blacklisted since' => 'Usu&aacute;rio est&aacute; na Lista Negra desde',
  'messages sent to this user' => 'mensagens enviadas a este usu&aacute;rio',
  'are you sure you want to delete this user from the blacklist' => 'Voc&ecirc; tem certeza que deseja retirar este usu&aacute;rio da lista negra',
- 'it should only be done with explicit permission from this user' => 'Isso s&oacute; pode ser feito com autoriza&ccedil;&aatilde;o expl&iacute;cita deste usu&aacute;rio',
+ 'it should only be done with explicit permission from this user' => 'Isso s&oacute; pode ser feito com autoriza&ccedil;&atilde;o expl&iacute;cita deste usu&aacute;rio',
  'remove User from Blacklist' => 'Remover Usu&aacute;rio da Lista Negra',
- 'user subscription history' => 'Hist&oacute;rico da Inscri&ccedil;&aatilde;o do Usu&aacute;rio',
+ 'user subscription history' => 'Hist&oacute;rico da Inscri&ccedil;&atilde;o do Usu&aacute;rio',
  'no details found' => 'Nenhum detalhe foi encontrado',
  'messages sent to this user' => 'mensagens enviadas a este usu&aacute;rio',
  'ip' => 'ip',
@@ -18,10 +22,7 @@ $lan = array(
  'info' => 'info',
  'blacklist info' => 'Info sobre Lista Negra',
  'value' => 'valor',
- 'subscription history' => 'Hist&oacute;rico de Inscri&ccedil;&aatilde;o', 
+ 'subscription history' => 'Evento', 
  'clicks' => 'cliques',
-
- 
- 
 );
 ?>
