@@ -50,8 +50,8 @@ if (!empty($GLOBALS["SessionTableName"])) {
 
 if (isset($_POST['setlanguage']) && $_POST['setlanguage'] && is_array($LANGUAGES[$_POST['setlanguage']])) {
   $_SESSION['adminlanguage'] = array(
-    "info" => $_POST['setlanguage'],
-    "iso" => $_POST['setlanguage'],
+    "info" => htmlentities($_POST['setlanguage']),
+    "iso" => htmlentities($_POST['setlanguage']),
     "charset" => $LANGUAGES[$_POST['setlanguage']][1],
   );
 }
