@@ -121,6 +121,8 @@ ini_set('error_prepend_string','<P><font color=red style=\"{font-size: 12px}\">S
   Please <a href="http://mantis.phplist.com">report a bug</a> when reporting the bug, please include URL and the entire content of this page.<br/>');
 
 function listName($id) {
+  $id = sprintf('%d',$id);
+  if (empty($id)) return '';
   global $tables;
   $req = Sql_Fetch_Row_Query(sprintf('select name from %s where id = %d',$tables["list"],$id));
   return $req[0] ? stripslashes($req[0]) : $GLOBALS['I18N']->get('Unnamed List');
@@ -358,7 +360,7 @@ function cleanEmail ($value) {
 }
 
 if (TEST && REGISTER)
-  $pixel = '<img src="http://phplist.tincan.co.uk/images/pixel.gif" width=1 height=1>';
+  $pixel = '<img src="http://powered.phplist.com/images/pixel.gif" width=1 height=1>';
 
 
 function timeDiff($time1,$time2) {
@@ -478,9 +480,10 @@ function logEvent($msg) {
   } else {
     $p = 'unknown page';
   }
+  $p = removeXss($p);
   if (Sql_Table_Exists($tables["eventlog"]))
   Sql_Query(sprintf('insert into %s (entered,page,entry) values(now(),"%s","%s")',$tables["eventlog"],
-    $p,addslashes($msg)));
+    sql_escape($p),htmlspecialchars(sql_escape($msg))));
 }
 
 ### process locking stuff
@@ -716,6 +719,8 @@ function cleanUrl($url,$disallowed_params = array('PHPSESSID')) {
 #    $uri .= '?p='.$params['p'];
 #  }
   $uri .= !empty($parsed['fragment']) ? '#'.$parsed['fragment'] : '';
+  ## 16597 - URLs shouldn't have ", so take them out
+  $uri = trim($uri,'"');
   return $uri;
 }
 
