@@ -389,6 +389,8 @@ while ($message = Sql_fetch_array($messages)) {
   # Check this and take anyone in that case.
   $numattr = Sql_Fetch_Row_Query("select count(*) from ".$tables["attribute"]);
 
+  ## 16552 - clear selection for each message
+  $user_attribute_query = '';
   if ($userselection && $numattr[0]) {
     $res = Sql_query($userselection);
     $num_users = Sql_Affected_rows($res);
