@@ -16,6 +16,7 @@ if (USEFCK && file_exists("./FCKeditor/fckeditor.php")) {
 } else {
   $usefck = 0;
 }
+$status = 'draft';
 
 // Verify that TinyMCE is available
 $useTinyMCE = 0;
@@ -132,22 +133,22 @@ if ($id) {
   if (!isset($_POST["forwardsubject"])) {
      $_POST["forwardsubject"] = "";
   }
-  else $_POST["forwardsubject"] = sprintf("%s", $_POST["forwardsubject"]);
+  else $_POST["forwardsubject"] = removeXSS($_POST["forwardsubject"]);
 
   if (!isset($_POST["forwardmessage"])) {
      $_POST["forwardmessage"] = "";
   }
-  else $_POST["forwardmessage"] = sprintf("%s", $_POST["forwardmessage"]);
+  else $_POST["forwardmessage"] = removeXSS($_POST["forwardmessage"]);
 
   if (!isset($_POST["forwardfooter"])) {
      $_POST["forwardfooter"] = "";
   }
-  else $_POST["forwardfooter"] = sprintf("%s", $_POST["forwardfooter"]);
+  else $_POST["forwardfooter"] = removeXSS($_POST["forwardfooter"]);
 
   if (!isset($_POST["msgsubject"])) {
-    $_POST["msgsubject"] = sprintf("%s",$_POST["subject"]);
+    $_POST["msgsubject"] = removeXSS($_POST["subject"]);
   } else {
-    $_POST['subject'] = sprintf("%s",$_POST['msgsubject']);
+    $_POST['subject'] = removeXSS($_POST['msgsubject']);
   }
   if ((!isset($_POST["year"]) || !is_array($_POST["year"])) && $_POST["embargo"] && $_POST["embargo"] != "0000-00-00 00:00:00") {
      $embargo->setDateTime($_POST["embargo"]);
@@ -276,6 +277,7 @@ if ($send || $sendtest || $prepare || $save) {
     } else {
       // Keep the status the same
       $status = $_POST["status"];
+      $status = preg_replace('/\W/','',$status);
     }
   } elseif ($send) {
     // We're sending - change state to "send-it" status!
@@ -333,16 +335,16 @@ if ($send || $sendtest || $prepare || $save) {
       'rsstemplate = "%s"  '.
       'where id  =  %d',
       $tables["message"],
-      addslashes($subject),
-      addslashes($from),
-      addslashes($_POST["tofield"]),
-      addslashes($_POST["replyto"]),
+      sql_escape($subject),
+      sql_escape($from),
+      sql_escape($_POST["tofield"]),
+      sql_escape($_POST["replyto"]),
       $_POST["embargo"],
       $_POST["repeatinterval"],
       $_POST["repeatuntil"],
-      addslashes($_POST["message"]),
-      addslashes($_POST["textmessage"]),
-      addslashes($_POST["footer"]),
+      sql_escape($_POST["message"]),
+      sql_escape($_POST["textmessage"]),
+      sql_escape($_POST["footer"]),
       $status,
       $htmlformatted,
       $_POST["sendformat"],
@@ -394,7 +396,7 @@ if ($send || $sendtest || $prepare || $save) {
   if (FORWARD_ALTERNATIVE_CONTENT && $_GET['tab'] == 'Forward') {
     foreach( array('forwardsubject', 'forwardmessage', 'forwardfooter') as $var) {
       Sql_Query(sprintf('replace into %s (name,id,data) values("%s",%d,"%s")',
-        $tables["messagedata"], $var, $messageid, addslashes($_REQUEST[$var])));
+        $tables["messagedata"], $var, $messageid, sql_escape($_REQUEST[$var])));
     }
   }
 
@@ -658,7 +660,7 @@ if ($send || $sendtest || $prepare || $save) {
 
     foreach ($emailaddresses as $address) {
       $address = trim($address);
-      $result = Sql_query(sprintf('select id,email,uniqid,htmlemail,rssfrequency,confirmed from %s where email = "%s"',$tables["user"],$address));
+      $result = Sql_query(sprintf('select id,email,uniqid,htmlemail,rssfrequency,confirmed from %s where email = "%s"',$tables["user"],sql_escape($address)));
       if ($user = Sql_fetch_array($result)) {
         if ( FORWARD_ALTERNATIVE_CONTENT && $_GET['tab'] == 'Forward') {
           if (SEND_ONE_TESTMAIL) {
@@ -937,7 +939,7 @@ if (sizeof($subqueries)) {
 
 // Pull in $footer variable from post
 if (isset($_POST["footer"]))
-  $footer = $_POST["footer"];
+  $footer = removeXss($_POST["footer"]);
 
 // If $id wasn't passed in (if it was passed, then $_POST should have
 // the database value in it already, and if it's empty, then we should
@@ -1338,6 +1340,10 @@ if (!$done) {
   if (!$_POST["testtarget"]) {
     $_POST["testtarget"] = $GLOBALS["developer_email"];
   }
+  ## sanitise the target
+  if (!is_email($_POST['testtarget'])) {
+    $_POST['testtarget'] = '';
+  }
 
   // Display the HTML for the "Send Test" button, and the input field for the email addresses
   $sendtest_content = sprintf('<hr /><table><tr><td valign="top">
@@ -1653,15 +1659,14 @@ if (!$done) {
 }
 print $sendtest_content;
 
-if (!$_POST["status"]) {
+if (empty($_POST["status"])) {
   $savecaption = $GLOBALS['I18N']->get('saveasdraft');
 } else {
   $savecaption = $GLOBALS['I18N']->get('savechanges');#"Save &quot;".$_POST["status"]."&quot; message edits";
-
 }
 print "<hr><table><tr><td><input type=submit name=\"save\" value=\"$savecaption\"></td></tr></table>\n<hr>\n";
 print "<input type=hidden name=id value=$id>\n";
-print "<input type=hidden name=status value=\"".$_POST["status"]."\">\n";
+print "<input type=hidden name=status value=\"".$status."\">\n";
 print '<input type=hidden name=expand value="0">';
 
 ?>
