@@ -441,7 +441,7 @@ function sendEmail ($messageid,$email,$hash,$htmlpref = 0,$rssitems = array(),$f
         $link = substr($link,0,-1);
       }
       $linkid = 0;
-#      print "LINK: $link<br/>";
+ #     print "LINK: ".htmlspecialchars($link)."<br/>";
       if ((preg_match('/^http|ftp/',$link) || preg_match('/^http|ftp/',$urlbase)) && $link != 'http://www.phplist.com' && !strpos($link,$clicktrack_root)) {
         # take off personal uids
         $url = cleanUrl($link,array('PHPSESSID','uid'));
@@ -505,7 +505,7 @@ if (0) {
     # or secure
     #https://user:password@www.website.com:2345/document.php?parameter=something%20&otherpar=somethingelse#anchor
 
-    preg_match_all('#(https?://[^\s\>\}\,]+)#mis',$textmessage,$links);
+    preg_match_all('#(https?://[^\s\>\}\,\"]+)#mis',$textmessage,$links);
 #    preg_match_all('#(https?://[a-z0-9\./\#\?&:@=%\-]+)#ims',$textmessage,$links);
 #    preg_match_all('!(https?:\/\/www\.[a-zA-Z0-9\.\/#~\?+=&%@-_]+)!mis',$textmessage,$links);
     ## sort the results in reverse order, so that they are replaced correctly
@@ -517,6 +517,7 @@ if (0) {
       if (preg_match('/\.$/',$link)) {
         $link = substr($link,0,-1);
       }
+#      print "LINK: ".htmlspecialchars($link)."<br/>";
   
       $linkid = 0;
       if (preg_match('/^http|ftp/',$link) && $link != 'http://www.phplist.com') {# && !strpos($link,$clicktrack_root)) {
