@@ -65,7 +65,7 @@ if (!isset($_POST) && isset($HTTP_POST_VARS)) {
   by the developers  but also helps build interest, traffic and use of
   PHPlist, which is beneficial to it's future development.
 
-  Michiel Dethmers, Tincan Ltd 2000,2006
+  Michiel Dethmers, phpList Ltd 2000,2006
 */
 include "admin/pagetop.php";
 if (isset($_GET['id'])) {
@@ -804,12 +804,26 @@ function forwardPage($id) {
       $subtitle = $GLOBALS['strForwardSubtitle'].' '.stripslashes($messagedata['subject']);
     }
   } #mid set
+  if (empty($mid)) {
+#    print 'Mid empty'; exit;
+    FileNotFound();
+  }
 
   ## get userdata
-  $req = Sql_Query("select * from {$tables["user"]} where uniqid = \"".$_REQUEST["uid"]."\"");
+  $req = Sql_Query("select * from {$tables["user"]} where uniqid = \"".sql_escape($_REQUEST["uid"])."\"");
   $userdata = Sql_Fetch_Array($req);
   $req = Sql_Query(sprintf('select * from %s where email = "%s"',$tables["user"],$forwardemail));
   $forwarduserdata = Sql_Fetch_Array($req);
+
+  ## verify that this subscriber actually received this message to forward, otherwise they're not allowed
+  $allowed = Sql_Fetch_Row_Query(sprintf('select userid from %s where userid = %d and messageid = %d',
+    $GLOBALS['tables']['usermessage'],$userdata['id'],$mid));
+  if ($allowed[0] != $userdata['id']) {
+    ## when sending a test email from an admin, the entry isn't there yet
+    if (empty($_SESSION['adminloggedin']) || $_SESSION['adminloggedin'] != $_SERVER['REMOTE_ADDR']) {
+      FileNotFound();
+    }
+  }
   
   #0011996: forward to friend - personal message
   # text cannot be longer than max, to prevent very long text with only linefeeds total cannot be longer than twice max
